@@ -328,7 +328,10 @@ class UI:
             config = self.job['param_rules'][i]
 
             if config['type'] == 'integer':
-                default_val = config['default_value']
+                if self.input_params is not None and i in self.input_params.keys():
+                    default_val = self.input_params[i]
+                else:
+                    default_val = config['default_value']
                 max_val = config['max']
                 min_val = config['min']
                 step_val = config['step']
@@ -347,7 +350,10 @@ class UI:
                     style=self.style, layout=self.layout
                 )
             if config['type'] == 'string_option':
-                default_val = config['default_value']
+                if self.input_params is not None and i in self.input_params.keys() and self.input_params[i] in config['options']:
+                    default_val = self.input_params[i]
+                else:
+                    default_val = config['default_value']
                 options = config['options']
                 self.param[i] = widgets.Dropdown(
                     options=options,
@@ -356,7 +362,10 @@ class UI:
                     style=self.style
                 )
             if config['type'] == 'string_input':
-                default_val = config['default_value']
+                if self.input_params is not None and i in self.input_params.keys():
+                    default_val = self.input_params[i]
+                else:
+                    default_val = config['default_value']
                 self.param[i] = widgets.Text(
                     description=i, value=default_val, style=self.style)
 
